#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: urls.py 10806 2018-03-02 04:29:05Z David $
#
# Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: David $
# $Date: 2018-03-02 12:29:05 +0800 (Fri, 02 Mar 2018) $
# $Revision: 10806 $

from django.conf.urls import url, include, patterns

urlpatterns = patterns('',
    # Editor.
    url(r'^', include('emencia.django.newsletter.urls')),
    url(r'^plus/editor/', include('Theophrastus.editor.urls')),

    # Cloud.
    url(r'^plus/cloud/', include('Theophrastus.cloud.urls')),

    # Newsletter.
    url(r'^newsletter/', include('Theophrastus.newsletter_extension.urls')),

    # Statistics.
    url(r'^statistics/',
        include('Theophrastus.statistics.urls.statistics')),

    # Subscribers.
    url(r'^subscribers/',
        include('Theophrastus.statistics.urls.subscribers')),

    # Integration.
    url(r'^integration/', include('Theophrastus.integration.urls')),

    # API.
    url(r'^api/', include('Theophrastus.api.urls')),

    # django-selectable.
    url(r'^newsletters/selectable/', include('selectable.urls')),
)
